FastParse

Derive Macro FastParse 

#[derive(FastParse)]
{
    // Attributes available to this derive:
    #[mplg]
}
Static-codegen variant of Parse. Emits one fn per grammar rule and inherent fast_recognize / fast_parse methods on the parser struct. The grammar file is read the same way (#[mplg = "..."]).

Uses mpl::fast::ParserState and the flat-token output instead of the trait-based Parser API.